.. highlight:: python

==============
FloatingWindow
==============

.. module:: vanilla
.. autoclass:: FloatingWindow
   :inherited-members:
   :members:


.. autoclass:: HUDFloatingWindow
   :members:
